==> mathomatic_15.1.1.orig.tar.gz: mathomatic-15.1.1/license.h <==
/*
 * This Mathomatic include file contains the current license notice.
 */

/* The following is the Mathomatic license notice, stored in a string. */
/* It is displayed by the "help copyright" command. */
char	*license_string =
"    Mathomatic computer algebra system\n"
"    Copyright (C) 1987-2010 George Gesslein II\n\n"

"    This library is free software; you can redistribute it and/or\n"
"    modify it under the terms of the GNU Lesser General Public\n"
"    License as published by the Free Software Foundation; either\n"
"    version 2.1 of the License, or (at your option) any later version.\n\n"
 
"    This library is distributed in the hope that it will be useful,\n"
"    but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
"    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU\n"
"    Lesser General Public License for more details.\n\n"
 
"    You should have received a copy of the GNU Lesser General Public\n"
"    License along with this library; if not, write to the Free Software\n"
"    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA\n\n"

"The full text of this license with details is contained in the file \"COPYING\"\n"
"in the Mathomatic source distribution obtained from http://mathomatic.org\n"
"All Mathomatic files are published under this license.\n\n"

"Chief author, maintainer, and copyright holder contact information:\n"
"  email:\n"
"    gesslein@linux.com\n"
"  postal address:\n"
"    George Gesslein II\n"
"    P.O. Box 224\n"
"    Lansing, New York  14882-0224\n"
"    USA\n";

==> mathomatic_15.5.2.orig.tar.gz: mathomatic-15.5.2/license.h <==
/*
 * This Mathomatic include file contains the current license notice.
 */

/* The following is the Mathomatic license notice, stored in a string. */
/* It is displayed by the "help copyright" command. */
char	*license_string =
"    Mathomatic computer algebra system\n"
"    Copyright (C) 1987-2011 George Gesslein II\n\n"

"    This library is free software; you can redistribute it and/or\n"
"    modify it under the terms of the GNU Lesser General Public\n"
"    License as published by the Free Software Foundation; either\n"
"    version 2.1 of the License, or (at your option) any later version.\n\n"
 
"    This library is distributed in the hope that it will be useful,\n"
"    but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
"    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU\n"
"    Lesser General Public License for more details.\n\n"
 
"    You should have received a copy of the GNU Lesser General Public\n"
"    License along with this library; if not, write to the Free Software\n"
"    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA\n\n"

"The full text of this license with details is contained in the file \"COPYING\"\n"
"in the Mathomatic source distribution, obtainable from www.mathomatic.org;\n"
"All Mathomatic software and associated files are published under this license.\n\n"

"Chief author, maintainer, and copyright holder contact information:\n"
"  email:\n"
"    gesslein@linux.com\n"
"  postal address:\n"
"    George Gesslein II\n"
"    P.O. Box 224\n"
"    Lansing, New York  14882-0224\n"
"    USA\n";
